VecMap

Struct VecMap 

pub struct VecMap<V, I: UnsignedNum = usize> { /* private fields */ }
The VecMap is a type of associative array that uses a Vec of Options to map unsigned integer keys to elements.

Implementations

Source

impl<V, I: UnsignedNum> VecMap<V, I>

pub fn new() -> Self

Constructs a new, empty VecMap. It will not allocate until elements are pushed onto it.

Examples
let map = VecMap::<()>::new();
pub fn with_capacity(capacity: usize) -> Self

Constructs a new, empty VecMap with the specified capacity. It will be able to hold exactly capacity elements without reallocating. If capacity is 0, it will not allocate.

Panic

Panics if the capacity overflows.

Examples
let map = VecMap::<()>::with_capacity(10);
assert_eq!(map.capacity(), 10);
pub fn capacity(&self) -> usize

Returns the number of elements the map can hold without reallocating.

Examples
let map = VecMap::<()>::with_capacity(10);
assert_eq!(map.capacity(), 10);
pub fn len(&self) -> usize

Returns the number of elements in the map, also referred to as its ‘length’.

Examples
let mut map = VecMap::<()>::new();
assert_eq!(map.len(), 0);
map.insert(1, ());
assert_eq!(map.len(), 1);
pub fn get(&self, i: &I) -> Option<&V>

Returns a reference to the value corresponding to the index i .

Examples
let mut map = VecMap::<i32>::new();
let idx = 2;
map.insert(idx, 123);

assert_eq!(map.get(&idx), Some(&123));
map.remove(&idx);
assert!(map.get(&idx).is_none());
pub fn get_mut(&mut self, i: &I) -> Option<&mut V>

Returns a mutable reference to the value corresponding to the index i .

Examples
let mut map = VecMap::<i32>::new();
let idx = 1;
map.insert(idx, 123);

*map.get_mut(&idx).unwrap() += 1;
assert_eq!(map.remove(&idx), Some(124));
assert!(map.get_mut(&idx).is_none());
pub fn clear(&mut self)

Clears the map, removing all values. Note that this method has no effect on the allocated capacity of the map.

Examples
let mut map = VecMap::<()>::new();
map.insert(1, ());
map.clear();
assert!(map.len() == 0);
pub fn insert(&mut self, i: I, v: V) -> Option<V>

Inserts value into the map, allocating more capacity if necessary. The existing key-value in the map is returned.

Panics

Panics if the capacity overflows.

Examples
let mut map = VecMap::<i32>::new();
let idx = 1;
assert!(map.insert(idx, 123).is_none());
assert_eq!(map.insert(idx, 456).unwrap(), 123);
assert!(map.insert(0, 123).is_none());
assert_eq!(*map.get(&idx).unwrap(), 456);
pub fn remove(&mut self, i: &I) -> Option<V>

Removes and returns the element at index i from the map if exists.

Examples
let mut map = VecMap::<i32>::new();
map.insert(1, 123);
assert_eq!(map.remove(&1), Some(123));
assert_eq!(map.remove(&1), None);
pub fn retain(&mut self, f: impl FnMut(&I, &mut V) -> bool)

Retains only the elements specified by the predicate, passing a mutable reference to it. In other words, removes all elements such that f(index, &value) returns false.

Examples
let mut map = VecMap::<i32>::new();
map.insert(1, 1);
map.insert(0, 2);
map.retain(|_, val| { if *val == 1 { *val = 3; true } else { false } });
assert_eq!(*map.get(&1).unwrap(), 3);
assert!(map.get(&0).is_none());
pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more elements to be inserted in the given map. The collection may reserve more space to avoid frequent reallocations. After calling reserve, capacity will be greater than or equal to self.len() + additional. Does nothing if capacity is already sufficient.

Panics

Panics if the capacity overflows.

Examples
let mut map = VecMap::<()>::new();
map.reserve(10);
assert!(map.capacity() >= 10);
pub fn iter(&self) -> Iter<'_, V, I>

Returns an iterator over the map.

Examples
let mut map = VecMap::<usize>::new();
for i in 0..10 {
    map.insert(i, i * i);
}

for (idx, value) in &map {
    println!("{} is at index {:?}", value, idx);
}
pub fn iter_mut(&mut self) -> IterMut<'_, V, I>

Returns an iterator that allows modifying each value over this map.

Examples
let mut map = VecMap::<usize>::new();
for i in 0..10 {
    map.insert(i, i * i);
}

for (_, value) in &mut map {
    *value += 5;
}